summaryrefslogtreecommitdiff
path: root/solenv/bin/modules/installer/ziplist.pm
diff options
context:
space:
mode:
Diffstat (limited to 'solenv/bin/modules/installer/ziplist.pm')
-rw-r--r--solenv/bin/modules/installer/ziplist.pm12
1 files changed, 6 insertions, 6 deletions
diff --git a/solenv/bin/modules/installer/ziplist.pm b/solenv/bin/modules/installer/ziplist.pm
index 7c66cdd6851c..c30bbb431ce1 100644
--- a/solenv/bin/modules/installer/ziplist.pm
+++ b/solenv/bin/modules/installer/ziplist.pm
@@ -639,7 +639,7 @@ sub replace_packagetype_in_pathes
}
####################################################
# Removing ending separators in pathes
####################################################
sub remove_ending_separator
@@ -667,7 +667,7 @@ sub replace_languages_in_pathes
{
my ( $patharrayref, $languagesref ) = @_;
- installer::logger::include_header_into_logfile("Replacing languages in include pathes:");
+ installer::logger::include_header_into_logfile("Replacing languages in include paths:");
my @patharray = ();
my $infoline = "";
@@ -691,7 +691,7 @@ sub replace_languages_in_pathes
installer::remover::remove_leading_and_ending_whitespaces(\$newline);
# Is it necessary to refresh the global array, containing all files of all include pathes?
if ( -d $newdir )
{
# Checking if $newdir is empty
@@ -731,7 +731,7 @@ sub list_all_files_from_include_path
{
my ( $patharrayref) = @_;
- installer::logger::include_header_into_logfile("Include pathes:");
+ installer::logger::include_header_into_logfile("Include paths:");
for ( my $i = 0; $i <= $#{$patharrayref}; $i++ )
{
@@ -790,7 +790,7 @@ sub set_default_productversion_if_required
}
####################################################
# Removing .. in pathes
####################################################
sub simplify_path
@@ -813,7 +813,7 @@ sub simplify_path
}
####################################################
# Removing ending separators in pathes
####################################################
sub resolve_relative_pathes
@@ -639,7 +639,7 @@ sub replace_packagetype_in_pathes
}
####################################################
-# Removing ending separators in pathes
+# Removing ending separators in paths
####################################################
sub remove_ending_separator
@@ -691,7 +691,7 @@ sub replace_languages_in_pathes
installer::remover::remove_leading_and_ending_whitespaces(\$newline);
- # Is it necessary to refresh the global array, containing all files of all include pathes?
+ # Is it necessary to refresh the global array, containing all files of all include paths?
if ( -d $newdir )
{
@@ -790,7 +790,7 @@ sub set_default_productversion_if_required
}
####################################################
-# Removing .. in pathes
+# Removing .. in paths
####################################################
sub simplify_path
@@ -813,7 +813,7 @@ sub simplify_path
}
####################################################
-# Removing ending separators in pathes
+# Removing ending separators in paths
####################################################
sub resolve_relative_pathes